In brief
========

.. image:: _static/favicon.png
    :alt: logo

HydrOffice is a research development environment for ocean mapping. It provides a collection of hydro-packages,
each of them dealing with a specific issue of the field.
The main goal is to speed up both algorithms testing and research-2-operation.

The BAG hydro-package collects tools for working with files in
`BAG format <https://en.wikipedia.org/wiki/Bathymetric_attributed_grid>`_.
BAG is a data format by the `ONS-WG <http://www.opennavsurf.org/>`_ (Open Navigation Surface Working Group).
